\name{ClassPP}
\alias{ClassPP}
\title{Projection Pursuit for Supervised Classification}
\description{
This package is for projection pursuit method for supervised classification.
}
 
\seealso{
PPindex.class \ PPindex.LDA \ PPindex.Lp \ PPindex.PDA

PP.optimize.anneal

PP.optimize.plot

PP.Tree

PP.classify
}
\references{
  Lee, E., Cook, D., and Klinke, S.(2002)
 \emph{Projection Pursuit indices for supervised classification}

}

\author{Eun-kyung Lee}

\keyword{multivariate}

\eof
\name{PP.Tree}
\title{Find PP tree structure}
\usage{
PP.Tree(PPmethod, i.class, i.data, weight = TRUE, r=NULL,lambda=NULL,...) 

}
\alias{PP.Tree}
\description{
Find tree structure using projection pursuit in each split.
}
\arguments{
  \item{PPmethod}{Selected PP index

  ``LDA" - LDA index

  ``Lp"  - Lp index;

  ``PDA"  - PDA index}
  \item{i.data}{A training data  without class information}
  \item{i.class}{class information}
  \item{weight}{weight flag using in LDA index}
  \item{r}{a parameter for \eqn{L_r} index}
  \item{lambda}{a parameter for PDA index}
 \item{...}{...}
}

\value{
\item{Tree.Struct}{Tree structure}
\item{Alpha.Keep}{1D projection of each split}
\item{C.Keep}{spliting rule for each split}
}
\references{
  Lee, E., Cook, D., and Klinke, S.(2002)
 \emph{Projection Pursuit indices for supervised classification}

}
\author{Eun-kyung Lee}

\seealso{\code{{PPindex.class}}, \code{{PP.optimize}}}

\examples{

data(iris)
n <- nrow(iris)
tot <- c(1:n)
n.train <- round(n*0.9)
train <- sample(tot,n.train)
test <- tot[-train]

Tree.result <- PP.Tree("LDA",iris[train,5],iris[train,1:4])
Tree.result
}
\keyword{tree}

\eof
\name{PP.classify}
\title{Predict class for the test set and calculate prediction error}
\usage{
PP.classify(test.data, true.class, Tree.result, Rule,...) 

}
\alias{PP.classify}
\description{
After finding tree structure, predict class for the test set and calculate prediction error.
}
\arguments{
  \item{test.data}{ the test dataset}
  \item{true.class}{true class of test dataset if available}
  \item{Tree.result}{the result of PP.Tree}
  \item{Rule}{split rule

  1 - mean of two group means

  2 - weighted mean of two group means
 
  3 - mean of max(left group) and min(right group)

  4 - weighted mean of max(left group) and min(right group)}
  \item{...}{...}
}

\value{
\item{predict.class}{predicted class}
\item{predict.error}{prediction error}
}
\references{
  Lee E., Cook D., and Klinke, S.  (2002)
 \emph{Projection Pursuit indices for supervised classification}

}
\author{Eun-kyung Lee}

\seealso{\code{{PPindex.class}}, \code{{ PP.optimize}},\code{{ PP.Tree}}}

\examples{

data(iris)
n <- nrow(iris)
tot <- c(1:n)
n.train <- round(n*0.9)
train <- sample(tot,n.train)
test <- tot[-train]

Tree.result <- PP.Tree("LDA",iris[train,5],iris[train,1:4])

tree.train <- PP.classify(iris[train,1:4],iris[train,5],Tree.result,Rule=1)
tree.train

tree.test <- PP.classify(iris[test,1:4],iris[test,5],Tree.result,Rule=1)
tree.test

}
\keyword{tree}

\eof
\name{PP.optimize}
\title{Find optimal Projection by maximizing selected PPindex}
\usage{
PP.optimize.random(PPmethod,projdim,data,class,std=TRUE,cooling=0.99,temp=1,r=NULL,lambda=NULL,weight=TRUE,...)
PP.optimize.anneal(PPmethod,projdim,data,class,std=TRUE,cooling=0.999,temp=1,energy=0.01,r=NULL,lambda=NULL,weight=TRUE,...)
PP.optimize.Huber(PPmethod,projdim,data,class,std=TRUE,cooling=0.99,temp=1,r=NULL,lambda=NULL,weight=TRUE,...)
PP.optimize.plot(PP.opt, data, class,std=TRUE)
}
\alias{PP.optimize.random}
\alias{PP.optimize.anneal}
\alias{PP.optimize.Huber}
\alias{PP.optimize.plot}

\description{
Find optimal projection using PP index.
}
\arguments{
  \item{PPmethod}{Selected PP index

  ``LDA" - LDA index

  ``Lp"  - Lp index;

  ``PDA"  - PDA index}

  \item{projdim}{dimension of projection that you want to find}
  \item{data}{data  without class information}
  \item{class}{class information}
  \item{std}{decide whether data will be standardized or not before applying projection pursuit} 
  \item{weight}{weight flag using in LDA index}
  \item{cooling}{parameter for optimization}
  \item{temp}{inital temperature for optimization}
  \item{energy}{parameter for simulated annealing optimization}
  \item{r}{a parameter for \eqn{L_r} index}
  \item{lambda}{a parameter for PDA index}
  \item{PP.opt}{the optimal projection}
  \item{...}{...}
}

\value{
\item{index.best}{PP index for optimal projected data}
\item{proj.best}{optimal projection}
}
\references{
  Lee E., Cook D., and Klinke, S.  (2002)
 \emph{Projection Pursuit indices for supervised classification}

}
\author{Eun-kyung Lee}

\seealso{\code{{PPindex.class}}}



\examples{
data(iris)

PP.opt<-PP.optimize.random("LDA",1,iris[,1:4],iris[,5],cooling=0.999,temp=1)

PP.opt$index.best
PP.optimize.plot(PP.opt,iris[,1:4],iris[,5])


PP.opt<-PP.optimize.anneal("LDA",1,iris[,1:4],iris[,5],cooling=0.999,temp=1,energy=0.01)
PP.opt$index.best

PP.optimize.plot(PP.opt,iris[,1:4],iris[,5])


PP.opt<-PP.optimize.Huber("LDA",2,iris[,1:4],iris[,5],cooling=0.999,r=1)
PP.opt$index.best
PP.optimize.plot(PP.opt,iris[,1:4],iris[,5])


}
\keyword{optimize}

\eof
\name{PPindex.class}
\title{Calculate Projection Pursuit index}
\usage{
 PPindex.class(PPmethod,data,class,weight=TRUE,r=NULL,lambda=NULL,...)
 PPindex.LDA(data,class, weight = TRUE, ...) 
 PPindex.Lp(data, class, r, ...) 
 PPindex.PDA(data,class,lambda,...)
}
\alias{PPindex.class}
\alias{PPindex.LDA}
\alias{PPindex.Lp}
\alias{PPindex.PDA}
\description{
For given projected data and class information, calculate projeciton pursuit index.
}
\arguments{
  \item{PPmethod}{Selected PP index

  ``LDA" - LDA index

  ``Lp"  - Lp index

  ``PDA"  - Entropy-class index}

  \item{data}{A data  without class information}
  \item{class}{class information}
  \item{weight}{weight flag using in LDA index}
  \item{r}{a parameter for \eqn{L^r} index}
  \item{lambda}{a parameter for PDA index} 
 \item{...}{...}

}

\value{
  The value is an projection pursuit index for given data.
}
\references{
  Lee, E., Cook, D., and Klinke, S.(2002)
 \emph{Projection Pursuit indices for supervised classification}

}
\author{Eun-kyung Lee}


\seealso{\code{{PP.optimize}}}

\examples{
data(iris)

PPindex.class("LDA",iris[,1:2],iris[,5])
PPindex.class("LDA",iris[,1:2],iris[,5],weight=FALSE)
PPindex.class("Lp",iris[,1:2],iris[,5],r=1)
PPindex.class("PDA",iris[,1:2],iris[,5],lambda=0.1)

}
\keyword{multivariate}

\eof
